# shine.inference

Bayesian inference engine with optional MAP initialization.

Wraps NumPyro's NUTS sampler with support for MAP pre-initialization
using Adam optimization to improve MCMC convergence.

::: shine.inference
